Beta-Sigma API
==================

.. currentmodule:: PyAstronomy.pyasl

BSBase (Base class for BSEqSamp and BSArbSamp)
-------------------------------------------------

.. autoclass:: BSBase
   :members:
   :private-members:

BSEqSamp (equidistant sampling)
---------------------------------

.. autoclass:: BSEqSamp
   :members:
   :private-members:


BSArbSamp (arbitrary sampling)
---------------------------------

.. autoclass:: BSArbSamp
   :members:
   :private-members:


SampCorr (sample correlation)
---------------------------------

.. autoclass:: SampCorr
   :members:
   :private-members:
